@@ -11,17 +11,17 @@ package Data::Section::Pluggable::Plugin::MyPlugin {
         return ('txt');
     }
 
-    sub process_content ($class, $dps, $content) {
+    sub process_content ($class, $dsp, $content) {
         $content =~ s/\s*\z//;  # trim trailing whitespace
         return "[$content]";
     }
 }
 
-my $dps = Data::Section::Pluggable->new
+my $dsp = Data::Section::Pluggable->new
                                   ->add_plugin('my_plugin');
 
 # prints '[Welcome to Perl]'
-say $dps->get_data_section('hello.txt');
+say $dsp->get_data_section('hello.txt');
 
 __DATA__
 @@ hello.txt
